@@ -12,7 +12,7 @@ use List::MoreUtils qw(none);
 use Scalar::Util qw(blessed);
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -49,7 +49,7 @@ sub new {
 		err "Parameter 'tube' is required.";
 	}
 	if (! blessed($self->{'tube'})
-		|| ! $self->{'tube'}->does('Map::Tube')) {
+		|| ! $self->{'tube'}->DOES('Map::Tube')) {
 
 		err "Parameter 'tube' must be 'Map::Tube' object.";
 	}
@@ -243,6 +243,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
